@@ -3,7 +3,7 @@ package Debian::AptContents;
 use strict;
 use warnings;
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 =head1 NAME
 
@@ -462,15 +462,11 @@ sub find_file_packages {
 =item find_perl_module_package( $module, $version )
 
 Given Perl module name (e.g. Foo::Bar), returns a L<Debian::Dependency> object
-representing the required Debian package and version. If the module is a core
-one, suitable dependency on perl is returned.
+representing the required Debian package and version. If the module is only in perl core,
+a suitable dependency on perl is returned.
 
-If the package is also available in a separate package, an alternative
-dependency is returned.
-
-In case the version of the currently running Perl interpreter is lower than the
-version in which the wanted module is available in core, the separate package
-is preferred. Otherwise the perl dependency is the first alternative.
+For dual-lifed modules, which are in perl and in a separate package, only
+the latter is returned, as the perl package has versioned Provides for them.
 
 =cut
 
@@ -503,27 +499,10 @@ sub find_perl_module_package {
         : ( $matches[0], $version )
     ) if @matches;
 
-    my $running_perl = $Config::Config{version};
-
     if ($core_dep) {
-
-        # the core dependency is satisfied by oldstable?
-        if ( $core_dep->ver <= $oldstable_perl ) {
-            # drop the direct dependency and remove the version
-            undef($direct_dep);
-
-            $core_dep->ver(undef);
-            $core_dep->rel(undef);
-        }
-
         if ($direct_dep) {
             # both in core and in a package.
-            if( $running_perl >= $core_dep->ver ) {
-                return Debian::Dependency->new("$core_dep | $direct_dep");
-            }
-            else {
-                return Debian::Dependency->new("$direct_dep | $core_dep");
-            }
+            return $direct_dep;
         }
         else {
             # only in core
@@ -556,7 +535,7 @@ sub find_perl_module_package {
 
 =item Copyright (C) 2008, 2009, 2010, 2017 Damyan Ivanov <dmn@debian.org>
 
-=item Copyright (C) 2016, gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2016, 2019 gregor herrmann <gregoa@debian.org>
 
 =back
 
