@@ -16,7 +16,7 @@ package Debian::Control::FromCPAN;
 use strict;
 use warnings;
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 use Carp qw(croak);
 
@@ -297,7 +297,7 @@ Scans the given hash of dependencies ( module => version ) and returns
 matching Debian package dependency specification (as an instance of
 L<Debian::Dependencies> class) and a list of missing modules.
 
-Perl core is searched first, then installed packages, then the APT contents.
+Installed packages and perl core are searched first, then the APT contents.
 
 If a DPKG::Parse::Available object is passed, also check the available package version
 
@@ -320,63 +320,65 @@ sub find_debs_for_modules {
 
         $version =~ s/^v// if $version;
 
-        my $dep;
+        my ( $dep, $core_dep, $direct_dep );
 
         require Debian::DpkgLists;
         if ( my $ver = is_core_module( $module, $version ) ) {
-            $dep = Debian::Dependency->new( 'perl', $ver );
+            $core_dep = Debian::Dependency->new( 'perl', $ver );
         }
-        elsif ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
+        if ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
             # core packages should be included above
             # it is normal to have them here, in case the version
             # requirement can't be satisfied by the current perl
             @pkgs = grep { !is_core_perl_package($_) } @pkgs;
 
-            $dep = Debian::Dependency->new(
-                  ( @pkgs > 1 )
-                ? [ map { { pkg => $_, ver => $version } } @pkgs ]
-                : ( $pkgs[0], $version )
-            );
+            if (@pkgs) {
+                $direct_dep = Debian::Dependency->new(
+                      ( @pkgs > 1 )
+                    ? [ map { { pkg => $_, ver => $version } } @pkgs ]
+                    : ( $pkgs[0], $version )
+                );
 
-            # Check the actual version available, if we've been passed
-            # a DPKG::Parse::Available object
-            if ( $dpkg_available ) {
-                my @available;
-                my @satisfied = grep {
-                    if ( my $pkg = $dpkg_available->get_package('name' => $_) ) {
-                        my $have_pkg = Debian::Dependency->new( $_, '=', $pkg->version );
-                        push @available, $have_pkg;
-                        $have_pkg->satisfies($dep);
+                # Check the actual version available, if we've been passed
+                # a DPKG::Parse::Available object
+                if ( $dpkg_available ) {
+                    my @available;
+                    my @satisfied = grep {
+                        if ( my $pkg = $dpkg_available->get_package('name' => $_) ) {
+                            my $have_pkg = Debian::Dependency->new( $_, '=', $pkg->version );
+                            push @available, $have_pkg;
+                            $have_pkg->satisfies($direct_dep);
+                        }
+                        else {
+                            warn qq(Unable to obtain version information for "$module" with DPKG::Parse::Available. )
+                                .qq(You may need to run "apt-cache dumpavail | dpkg --merge-avail");
+                        }
+                    } @pkgs;
+                    unless ( @satisfied ) {
+                        print "$module is available locally as @available, but does not satisfy $version\n"
+                            if $verbose;
+                        push @missing, $module;
                     }
-                    else {
-                        warn qq(Unable to obtain version information for "$module" with DPKG::Parse::Available. )
-                            .qq(You may need to run "apt-cache dumpavail | dpkg --merge-avail");
-                    }
-                } @pkgs;
-                unless ( @satisfied ) {
-                    print "$module is available locally as @available, but does not satisfy $version\n"
-                        if $verbose;
-                    push @missing, $module;
                 }
-            }
-            else {
-                warn "DPKG::Parse not available. Not checking version of $module.";
+                else {
+                    warn "DPKG::Parse not available. Not checking version of $module.";
+                }
             }
         }
 
-        if (!$dep && $apt_contents) {
-            $dep = $apt_contents->find_perl_module_package( $module, $version );
+        if (!$direct_dep && $apt_contents) {
+            $direct_dep = $apt_contents->find_perl_module_package( $module, $version );
 
             # Check the actual version in APT, if we've got
             # a AptPkg::Cache object to search
-            if ( $dep && $aptpkg_cache ) {
-                my $pkg = $aptpkg_cache->{$dep->pkg};
+            if ( $direct_dep && $aptpkg_cache ) {
+                my $pkg = $aptpkg_cache->{$direct_dep->pkg};
                 if ( my $available = $pkg->{VersionList} ) {
                     for my $v ( @$available ) {
-                        my $d = Debian::Dependency->new( $dep->pkg, '=', $v->{VerStr} );
-                        last if $d->satisfies($dep); # exit loop if we have a good version; otherwise:
+                        my $d = Debian::Dependency->new( $direct_dep->pkg, '=', $v->{VerStr} );
+                        last if $d->satisfies($direct_dep); # exit loop if we have a good version; otherwise:
                         push @missing, $module;
-                        print "$module package in APT ($d) does not satisfy $dep"
+                        print "$module package in APT ($d) does not satisfy $direct_dep"
                             if $verbose;
                     }
                 }
@@ -384,59 +386,12 @@ sub find_debs_for_modules {
         }
 
 
+        $dep = $direct_dep || $core_dep;
         $dep->rel($ver_rel) if $dep and $ver_rel and $dep->ver;
 
         my $mod_ver = join( " ", $module, $ver_rel // (), $version || () );
         if ($dep) {
-            if ($verbose) {
-                if ( $dep->pkg and $dep->pkg eq 'perl' ) {
-                    print "= $mod_ver is in core";
-                    print " since " . $dep->ver if $dep->ver;
-                    print "\n";
-                }
-                else {
-                    print "+ $mod_ver found in $dep\n";
-                }
-            }
-
-            my $target_perl_version = $^V;
-            $target_perl_version =~ s/^v//;
-            $target_perl_version = Dpkg::Version->new($target_perl_version);
-
-            if (    $dep->pkg
-                and $dep->pkg eq 'perl'
-                and $dep->ver
-                and $dep->ver > $target_perl_version )
-            {
-                print "  ! $dep is too new. Adding alternative dependency\n"
-                    if $verbose;
-
-                my $alt_dep;
-
-                if ( my @pkgs = Debian::DpkgLists->scan_perl_mod($module) ) {
-                    @pkgs = grep { !is_core_perl_package($_) } @pkgs;
-
-                    $alt_dep = Debian::Dependency->new(
-                          ( @pkgs > 1 )
-                        ? [ map { { pkg => $_, ver => $version } } @pkgs ]
-                        : ( $pkgs[0], $version )
-                    ) if @pkgs;
-                }
-
-                if ( not $alt_dep and $apt_contents) {
-                    $alt_dep
-                        = $apt_contents->find_perl_module_package( $module,
-                        $version );
-                }
-
-                $alt_dep
-                    //= Debian::Dependency->new(
-                    $self->module_name_to_pkg_name($module),
-                    '>=', $version );
-
-                $dep = Debian::Dependency->new("$alt_dep | $dep");
-                #print "    $dep\n";
-            }
+            print "+ $mod_ver found in $dep\n" if $verbose
         }
         else {
             print "- $mod_ver not found in any package\n";
@@ -653,6 +608,8 @@ sub module_name_to_pkg_name {
 
 Copyright (C) 2009, 2010, 2012 Damyan Ivanov L<dmn@debian.org>
 
+Copyright (C) 2019 gregor herrmann L<gregoa@debian.org>
+
 This program is free software; you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 2 as published by the Free
 Software Foundation.
