@@ -3,7 +3,7 @@ package DhMakePerl::Command::Packaging;
 use strict;
 use warnings;
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 use feature 'switch';
 
@@ -46,7 +46,7 @@ use Text::Balanced qw(extract_quotelike);
 use Text::Wrap qw(fill);
 use User::pwent;
 
-use constant debstdversion => '4.3.0';
+use constant debstdversion => '4.4.0';
 
 our %DEFAULTS = (
 );
@@ -908,14 +908,6 @@ sub create_rules {
     chmod( 0755, $file ) or die "chmod($file): $!";
 }
 
-sub create_compat {
-    my ( $self, $file ) = @_;
-
-    my $fh = $self->_file_w($file);
-    $fh->print( $self->cfg->dh, "\n" );
-    $fh->close;
-}
-
 sub update_file_list( $ % ) {
     my ( $self, %p ) = @_;
 
@@ -997,7 +989,8 @@ sub create_copyright {
     # Absence of author should have already been reported in the
     # Header section
     push @res,
-        "Copyright: " . ( $cprt_year ? "$cprt_year, " : '' ) . $cprt_author;
+        'Copyright: ' . ( $cprt_year ? $cprt_year : '<INSERT COPYRIGHT YEAR(S) HERE>' )
+        . ", $cprt_author";
 
     # This is far from foolproof, but usually works with most
     # boilerplate-generated modules.
@@ -1480,14 +1473,7 @@ sub discover_utility_deps {
     else {
         $build_deps->add('perl');
     }
-    $build_deps->add( Debian::Dependency->new( 'debhelper', $debhelper_version ) );
-
-    $self->explained_dependency(
-        'Module::Build::Tiny',
-        $build_deps,
-        'debhelper (>= 9.20140227~)'
-    ) if ( $build_deps->has('libmodule-build-tiny-perl') or
-          $build_deps_indep->has('libmodule-build-tiny-perl') );
+    $build_deps->add( Debian::Dependency->new( 'debhelper-compat', '=', $debhelper_version ) );
 
     for ( @{ $self->rules->lines } ) {
         $self->explained_dependency(
@@ -1521,17 +1507,20 @@ sub discover_utility_deps {
         ) if (/dh\s+.*--with[= ]perl[-_]openssl/);
     }
 
-    # Ensure both libmodule-build{,tiny}-perl and perl are in B-D
-    # (and not in B-D-I).
+    # Ensure libmodule-build{,tiny}-perl/libmodule-build-using-pkgconfig-perl
+    # and perl are in B-D (and not in B-D-I).
     if ( $self->module_build eq 'Module-Build' ) {
         my ($mb)   = $build_deps_indep->remove('libmodule-build-perl');
         my ($mbt)  = $build_deps_indep->remove('libmodule-build-tiny-perl');
+        my ($mbup) = $build_deps_indep->remove('libmodule-build-using-pkgconfig-perl');
         my ($perl) = $build_deps_indep->remove('perl');
         $perl ||= 'perl';
         $self->explained_dependency( 'Module::Build', $build_deps,
             "$mb" ) if $mb;
         $self->explained_dependency( 'Module::Build::Tiny', $build_deps,
             "$mbt" ) if $mbt;
+        $self->explained_dependency( 'Module::Build::Using::PkgConfig', $build_deps,
+            "$mbup" ) if $mbup;
         $self->explained_dependency( 'Module::Build{,::Tiny}', $build_deps,
             "$perl" );
     }
@@ -1677,6 +1666,42 @@ sub create_upstream_metadata {
     YAML::XS::DumpFile( File::Spec->catfile( $dir, 'metadata' ), \%upstream );
 }
 
+=item cme_fix_dpkg_control
+
+The equivalent of letting cme(1) reformat and fix F<debian/control>.
+
+=cut
+
+sub cme_fix_dpkg_control {
+    my ( $self, $dir ) = @_;
+
+    if (eval {
+            require Config::Model;
+            require Config::Model::Dpkg;
+        }
+        )
+    {
+        print "I: Using Config::Model::Dpkg\n" if $self->cfg->verbose;
+        if ( !$self->cfg->network ) {
+            warn "W: Config::Model::Dpkg needs network access, and we are running with --no-network";
+            return;
+        }
+        my $model    = Config::Model->new();
+        my $instance = $model->instance(
+            root_class_name => 'Dpkg::Control',
+            root_dir        => $dir,
+        );
+
+        # potentially apply fixes
+        $instance->apply_fixes();
+        # force write even without changes to get reformatting
+        $instance->save( force => 1 );
+    } else {
+        warn
+            "W: Config::Model::Dpkg not found. You might want to install libconfig-model-dpkg-perl";
+    }
+}
+
 =back
 
 =cut
@@ -1711,7 +1736,7 @@ sub _file_w {
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2018 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2019 gregor herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007-2013 Damyan Ivanov <dmn@debian.org>
 
