@@ -2,7 +2,7 @@ package DhMakePerl::Command::make;
 
 use warnings;
 use strict;
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 use 5.010;    # we use smart matching
 
 use base 'DhMakePerl::Command::Packaging';
@@ -208,8 +208,8 @@ sub execute {
         }
     }
     $self->control->write( $self->debian_file('control') );
+    $self->cme_fix_dpkg_control( $self->main_dir );
 
-    $self->create_compat( $self->debian_file('compat') );
     $self->create_watch( $self->debian_file('watch') );
 
     #create_readme("$debiandir/README.Debian");
@@ -557,9 +557,9 @@ sub create_watch {
 
     my $fh = $self->_file_w($filename);
 
-    my $version_re = 'v?(\d[\d.-]*)\.(?:tar(?:\.gz|\.bz2)?|tgz|zip)';
+    my $version_re = 'v?@ANY_VERSION@@ARCHIVE_EXT@';
 
-    $fh->printf( "version=3\n%s   .*/%s-%s\$\n",
+    $fh->printf( "version=4\n%s   .*/%s-%s\$\n",
         $self->upsurl, $self->perlname, $version_re );
     $fh->close;
 }
@@ -902,7 +902,7 @@ L<https://bugs.debian.org/dh-make-perl>
 
 =item Copyright (C) 2006 Frank Lichtenheld <djpig@debian.org>
 
-=item Copyright (C) 2007-2014 Gregor Herrmann <gregoa@debian.org>
+=item Copyright (C) 2007-2019 Gregor Herrmann <gregoa@debian.org>
 
 =item Copyright (C) 2007,2008,2009,2010,2011,2012,2015 Damyan Ivanov <dmn@debian.org>
 
