@@ -12,7 +12,7 @@ This module implements the I<refresh> command of L<dh-make-perl(1)>.
 
 use strict; use warnings;
 
-our $VERSION = '0.105';
+our $VERSION = '0.106';
 
 use base 'DhMakePerl::Command::Packaging';
 use Debian::Control::FromCPAN;
@@ -64,9 +64,8 @@ sub execute {
     print "Found examples: @{ $self->examples }\n"
         if @{ $self->examples } and $self->cfg->verbose;
 
-    if ( $self->cfg->only->{only} ) {
+    if ( $self->cfg->only->{rules} ) {
         $self->create_rules;
-        $self->create_compat( $self->debian_file('compat') );
     }
 
     if ( $self->cfg->only->{examples} ) {
@@ -102,7 +101,10 @@ sub execute {
         $control->prune_perl_deps();
 
         $self->backup_file( $self->debian_file('control') );
+        $self->backup_file( $self->debian_file('compat') );
+
         $control->write( $self->debian_file('control') );
+        $self->cme_fix_dpkg_control( $self->main_dir );
     }
 
     print "--- Done\n" if $self->cfg->verbose;
@@ -232,7 +234,7 @@ sub drop_quilt {
 
 =item Copyright (C) 2008, 2009, 2010 Damyan Ivanov <dmn@debian.org>
 
-=item Copyright (C) 2010, 2014 gregor herrmann <gregoa@debian.org>
+=item Copyright (C) 2010, 2014, 2019 gregor herrmann <gregoa@debian.org>
 
 =back
 
